package cluster

// SyncAll updates all config files
func (m *Cluster) SyncAll() error {
	for _, fn := range []func() error{
		m.SyncAllWireguard,
		m.SyncAllCeph,
		m.WriteHosts,
	} {
		if err := fn(); err != nil {
			return err
		}
	}

	return nil
}

// SyncAllWireguard updates all wireguard config files
func (m *Cluster) SyncAllWireguard() error {
	var err error

	for ring := 0; ring < RingsCount; ring++ {
		err = m.WriteWireguardKeys(ring)
		if err != nil {
			return err
		}

		err = m.SyncWireguardConfig(ring)
		if err != nil {
			return err
		}
	}

	return nil
}

// SyncAllCeph updates the ceph.conf file
func (m *Cluster) SyncAllCeph() error {
	cfg, err := m.GenCephConfig()
	if err != nil {
		return err
	}

	return m.WriteCephConfig(cfg)
}
